## ----wrapri-------------------------------------------------------------------
library("wrapr")
wrapr::defineLambda(name = "l")
ls()

## ----fsq1---------------------------------------------------------------------
l(x, x^2)

## ----fsq2---------------------------------------------------------------------
sapply(1:4, l(x, x^2))

## ----fsqp---------------------------------------------------------------------
1:4 %.>% { .^2 }

## ----ft-----------------------------------------------------------------------
l(x, y, x + 3*y)

